@@ -1,11 +1,13 @@
-from .framework import (Thread, Profiling, CommandQueueExtended, Private, Scalar, Local, Global, Constant, Function, Kernel,
+from .emulation import use_existing_file_for_emulation
+from .framework import (Thread, Profiling, CommandQueueExtended, Private, Scalar, Local, Global, Constant, Function,
+                        Kernel,
                         Program, get_thread, get_device, get_vec_size, LocalArray, HashArray, Helpers, Types,
                         scalar_type_from_vec_type, KernelGridType, KernelArgTypes, int_safe)
-from .emulation import set_b_use_existing_file_for_emulation
 from .helpers.general import (typed_partial)
-from .components.copy_array_region import (CopyArrayRegion, Slice, cl_set)
-from .components.sumalongaxis import SumAlongAxis
-from .components.fft import (Fft, IFft, FftStageBuilder)
-from .components.transpose import Transpose
 from .types.utilities_np_cl import (match_vec_size, c_name_from_dtype, is_complex_type, is_vector_type, VEC_INDICES,
                                     match_integer_type_for_select)
+from .components.copy_array_region import (CopyArrayRegion, Slice, cl_set)
+from .components.fft import (Fft, IFft, FftStageBuilder)
+from .components.sumalongaxis import SumAlongAxis
+from .components.transpose import Transpose
+
